.. _remote-targets-api-label:

Remote Systems and Targets
==========================

See :ref:`remote-targets-label` for an educational explanation.

.. autoclass:: b2luigi.core.remote_target.RemoteFileSystem
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: b2luigi.RemoteTarget
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: b2luigi.XRootDSystem
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: b2luigi.WebDAVSystem
    :members:
    :undoc-members:
    :show-inheritance:
